| Title: | R Package Template |
|---|---|
| Description: | R package template with GitHub Actions workflows included. |
| Authors: | insightsengineering [aut, cre] |
| Maintainer: | insightsengineering <[email protected]> |
| License: | Apache License 2.0 | file LICENSE |
| Version: | 0.1.0.9213 |
| Built: | 2026-06-02 15:03:37 UTC |
| Source: | https://github.com/insightsengineering/r.pkg.template |
Greet a person and appropriately capitalize their name.
hello(name = "your name")hello(name = "your name")
name |
Your name (character string; e.g. "john doe"). |
A character string, capitalized to title case.
hello("james bond")hello("james bond")
Greet a person and appropriately capitalize their name as a Plumber API.
plumber_api(...)plumber_api(...)
... |
Additional arguments to plumber::pr_run() |
Plumber API showcasing the personal greeting feature.
Greet a person and appropriately capitalize their name as a Shiny app.
shiny_app()shiny_app()
Shiny app showcasing the personal greeting feature.